core

#

API Docs for: 0.0.2
Show: Inherited Protected Private Deprecated

Browse to a module or class using the sidebar to view its API documentation.

## Keyboard Shortcuts

- Press `s` to focus the API search box.

- Use `Up` and `Down` to select classes, modules, and search results.

- With the API search box or sidebar focused, use `⌘-Left` or `⌘-Right` to switch sidebar tabs.

- With the API search box or sidebar focused, use `Ctrl+Left` and `Ctrl+Right` to switch sidebar tabs.